@@ -75,7 +75,9 @@ def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
 
     prefix = getattr(sys, "prefix", "")
     if venv_name not in prefix and create_venv:
-        typer.echo("no venv detected, will make own now")
+        typer.echo(
+            "No venv is active, will check to see if one exists and make one if not."
+        )
         venv_path = Path(venv_name)
         if not venv_path.exists():
             print("VENV PATH", venv_path)
@@ -89,7 +91,7 @@ def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
 
 @app.command()
 def version():
-    typer.echo("6")
+    typer.echo("7")
 
 
 if __name__ == "__main__":
